@@ -26,14 +26,12 @@ def test_read_conllx(datadir):
 
 def test_load_conllx(datadir):
     with open(datadir / "corpus.conllx") as fd:
-        data = fd.read()
+        result = list(load_conllx(fd))
+        assert len(result) == 3
 
-    result = load_conllx(data)
-    assert len(result) == 3
-
-    # result[2] expected to be ['A', ' ', 'c', 'a', 'r']
-    assert len(result[2].word_lines) == 5
-    assert result[2].word_lines[1] == " "
+        # result[2] expected to be ['A', ' ', 'c', 'a', 'r']
+        assert len(result[2].word_lines) == 5
+        assert result[2].word_lines[1] == " "
 
 
 @pytest.mark.skip("not ready")
