@@ -1,22 +1,20 @@
-import json
-from typing import List, Tuple
 import io
-
-from tqdm import tqdm
+import json
+from typing import Generator, List, Tuple
 
 from tokenizer_tools.conllz.sentence import SentenceX
 
 Block = List[Tuple[int, str]]
 
 
-def line_generator(fd) -> str:
+def line_generator(fd) -> Generator[str, None, None]:
     for raw_line in fd:
         # remove newline
         line = raw_line.rstrip("\n\r")
         yield line
 
 
-def block_generator(lines) -> Block:
+def block_generator(lines) -> Generator[Block, None, None]:
     block = []
     for line_num, line_str in enumerate(lines, start=1):
         if not line_str:  # empty line
@@ -35,10 +33,10 @@ def block_generator(lines) -> Block:
         yield block
 
 
-def load_conllx(fd: io.TextIOWrapper) -> List[SentenceX]:
+def load_conllx(fd: io.TextIOWrapper) -> Generator[SentenceX, None, None]:
     lines = line_generator(fd)
     blocks = block_generator(lines)
-    for block in tqdm(blocks):
+    for block in blocks:
         yield parse_block_to_sentence(block)
 
 
@@ -69,10 +67,10 @@ def parse_block_to_sentence(block: Block) -> SentenceX:
     return sentence
 
 
-def read_conllx(input_fd):
+def read_conllx(input_fd) -> List[SentenceX]:
     return list(load_conllx(input_fd))
 
 
-def read_conllx_from_string(str_content):
+def read_conllx_from_string(str_content) -> List[SentenceX]:
     fd = io.StringIO(str_content)
     return list(load_conllx(fd))
