@@ -3,6 +3,7 @@ from typing import Union, List, Tuple, Callable
 import numpy as np
 from sklearn.model_selection import train_test_split
 from fuzzywuzzy import process
+from tqdm import tqdm
 
 from tokenizer_tools.conllz.reader import load_conllx
 from tokenizer_tools.tagset.NER.BILUO import BILUOEncoderDecoder
@@ -12,6 +13,8 @@ from tokenizer_tools.converter.offset_to_sentence import offset_to_sentence
 from tokenizer_tools.tagset.offset.corpus_statistics import CorpusStatistics
 from tokenizer_tools.tagset.offset.document import Document
 from tokenizer_tools.tagset.offset.document_compare_ways import DocumentCompareWays
+from tokenizer_tools.tagset.offset.corpus_stream_writer import CorpusStreamWriter
+from tokenizer_tools.tagset.offset.corpus_stream_reader import CorpusStreamReader
 
 
 class Corpus(List[Document]):
@@ -34,7 +37,7 @@ class Corpus(List[Document]):
         offset_data_list = []
 
         with open(data_file, "rt") as fd:
-            for sentence in load_conllx(fd):
+            for sentence in tqdm(load_conllx(fd)):
                 offset_data, result = conllx_to_offset(sentence)
 
                 offset_data_list.append(offset_data)
@@ -196,3 +199,11 @@ class Corpus(List[Document]):
         sorted_tags = ["O"] + sorted(tags_except_oscar)
 
         return sorted_tags
+
+    @classmethod
+    def stream_writer(cls, file_path: str) -> CorpusStreamWriter:
+        return CorpusStreamWriter(file_path)
+
+    @classmethod
+    def stream_reader(cls, file_path: str) -> CorpusStreamReader:
+        return CorpusStreamReader(file_path)
