@@ -134,5 +134,33 @@ class Document(Sequence):
 
         parse Markdown string like: `[明天](日期)下雨吗？` into Document object
         """
+        from mistletoe import Document as CommonMarkDocument
+        from mistletoe.span_token import Link, RawText
+        from tokenizer_tools.tagset.offset.span import Span
+        from tokenizer_tools.tagset.offset.span_set import SpanSet
 
-        raise NotImplementedError()
+        md_doc = CommonMarkDocument(text)
+
+        tokens = []
+        spans = []
+
+        for item in md_doc.children[0].children:
+            if isinstance(item, Link):
+                title = item.children[0].content
+                target = item.target
+
+                start = len(tokens)
+                span = Span(start=start, end=start + len(title), entity=target)
+                spans.append(span)
+                tokens.extend(title)
+            elif isinstance(item, RawText):
+                content = item.content
+                tokens.extend(content)
+
+        doc = cls(tokens)
+        span_set = SpanSet()
+        span_set.host = doc
+        span_set.extend(spans)
+        doc.span_set = span_set
+
+        return doc
